Module shellflip::restart_coordination_socket
source · Expand description
Communication with a running process over a unix domain socket.
Structs
- Represents the restart coordination socket, used for communicating with a running oxy process. This is used to trigger a restart and receive notification of its completion or failure.
Enums
- Represents any message that may be sent over the socket.
- A request message that expects a response.
- A response to a request message.